membership

# XMLRésuméLibrary: User Guide

major | Element Reference | memberships

## Name

membership — A professional membership

## Synopsis

### Content Model

    (title?,(organization,location?)?,(date|period)?,description?)

### Attributes

Name | Type | Default
--- | --- | ---
id | ID | None
targets | CDATA | None

## Description

The `membership` element contains information about a person's membership in a professional organization.

### Parents

`membership` may be contained in these elements: `memberships`

### Attributes

`id`

  A string used to uniquely identify a membership. The membership may then be referred to by this identifier.

## Examples

For examples, see `memberships`.

major | Element Reference | memberships